>From 987af897dadcaebd4dda75535ebf13a9ee1a5480 Mon Sep 17 00:00:00 2001
From: Erwan Tulou <erwan10@videolan.org>
Date: Sat, 11 Jul 2009 23:08:09 +0200
Subject: [PATCH] still images: support for file:///path/image.ext

---
 modules/access/fake.c |   33 ++++++++++++++++++---------------
 1 files changed, 18 insertions(+), 15 deletions(-)
 mode change 100644 => 100755 modules/access/fake.c

diff --git a/modules/access/fake.c b/modules/access/fake.c
old mode 100644
new mode 100755
index 77ee197..d73c3f8
--- a/modules/access/fake.c
+++ b/modules/access/fake.c
@@ -73,6 +73,7 @@ vlc_module_begin ()
                  true )
 
     add_shortcut( "fake" )
+    add_shortcut( "file" )
     set_capability( "access_demux", 10 )
     set_callbacks( Open, Close )
 vlc_module_end ()
@@ -100,29 +101,31 @@ static int Open( vlc_object_t *p_this )
     demux_sys_t *p_sys;
     es_format_t fmt;
 
-    if( *p_demux->psz_access != '\0' )
+    if( !strcmp( p_demux->psz_access, "fake" ) )
     {
-        /* if an access is provided, then it has to be "fake" */
-        if( strcmp( p_demux->psz_access, "fake" ) )
-            return VLC_EGENERIC;
-
         msg_Dbg( p_demux, "fake:// access_demux detected" );
     }
     else
     {
-       /**
-        * access is not provided,
-        * then let's see if path could be an image
-        **/
-
-        if( !p_demux->psz_path || !*p_demux->psz_path )
+        /* in case of no access or file access,
+         * path is tested to detect if it refers to a still image
+         */
+        if( !*p_demux->psz_path )
             return VLC_EGENERIC;
 
-        vlc_fourcc_t i_codec = image_Ext2Fourcc( p_demux->psz_path );
-        if( !i_codec )
+        if( !strcmp( p_demux->psz_access, "" ) ||
+            !strcmp( p_demux->psz_access, "file" ) )
+        {
+            vlc_fourcc_t i_codec = image_Ext2Fourcc( p_demux->psz_path );
+            if( !i_codec )
+                return VLC_EGENERIC;
+            msg_Dbg( p_demux, "still image detected with %4.4s codec",
+                              (const char*)&i_codec );
+        }
+        else
+        {
             return VLC_EGENERIC;
-        msg_Dbg( p_demux, "still image detected with codec format %4.4s",
-                 (const char*)&i_codec );
+        }
     }
 
     if( p_demux->psz_path && *p_demux->psz_path )
-- 
1.5.6.5

